Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/corert.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJan Kotas <jkotas@microsoft.com>2015-11-14 03:54:12 +0300
committerJan Kotas <jkotas@microsoft.com>2015-11-14 04:11:57 +0300
commit636f8d3a976044ebb5b70d32dfdca42af4391f49 (patch)
tree755ad15d0b05610a99b1c00d5ec98646d9941377 /src/JitInterface
parent3c1639cbf1f0ea9708b8addf8cbd624b024d1d34 (diff)
Rename ILToNative
- Rename the compiler .exe to ilc.exe - Rename ILToNative.* to ILCompiler.* everywhere else
Diffstat (limited to 'src/JitInterface')
-rw-r--r--src/JitInterface/src/CorInfoImpl.cs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/JitInterface/src/CorInfoImpl.cs b/src/JitInterface/src/CorInfoImpl.cs
index 82947a0ed..fa945c710 100644
--- a/src/JitInterface/src/CorInfoImpl.cs
+++ b/src/JitInterface/src/CorInfoImpl.cs
@@ -14,7 +14,7 @@ using Internal.TypeSystem.Ecma;
using Internal.IL;
-using ILToNative;
+using ILCompiler;
namespace Internal.JitInterface
{
@@ -226,7 +226,7 @@ namespace Internal.JitInterface
CorInfoType corInfoRetType = asCorInfoType(signature.ReturnType, out sig.retTypeClass);
sig._retType = (byte)corInfoRetType;
- sig.retTypeSigClass = sig.retTypeClass; // The difference between the two is not relevant for ILToNative
+ sig.retTypeSigClass = sig.retTypeClass; // The difference between the two is not relevant for ILCompiler
sig.flags = 0; // used by IL stubs code